@@ -6,8 +6,10 @@ import os
 import json
 import multiprocessing
 import pandas as pd
+import platform
 import math
 import time as ttime
+import copy
 from distutils.version import LooseVersion
 
 import logging
@@ -31,10 +33,35 @@ warnings.filterwarnings("ignore")
 sep_v = os.sep
 
 try:
+    beamline_name = None
+
+    # Attempt to find the configuration file first
     config_path = "/etc/pyxrf/pyxrf.json"
-    with open(config_path, "r") as beamline_pyxrf:
-        beamline_config_pyxrf = json.load(beamline_pyxrf)
-        beamline_name = beamline_config_pyxrf["beamline_name"]
+    if os.path.isfile(config_path):
+        try:
+            with open(config_path, "r") as beamline_pyxrf:
+                beamline_config_pyxrf = json.load(beamline_pyxrf)
+                beamline_name = beamline_config_pyxrf["beamline_name"]
+        except Exception as ex:
+            raise IOError(f"Error while opening configuration file {config_path!r}") from ex
+
+    else:
+        # Otherwise try to identify the beamline using host name
+        hostname = platform.node()
+        beamline_names = {
+            "xf03id": "HXN",
+            "xf05id": "SRX",
+            "xf08bm": "TES",
+            "xf04bm": "XFM",
+        }
+
+        for k, v in beamline_names.items():
+            if hostname.startswith(k):
+                beamline_name = v
+
+    if beamline_name is None:
+        raise Exception("Beamline is not identified")
+
     if beamline_name == "HXN":
         from pyxrf.db_config.hxn_db_config import db
     elif beamline_name == "SRX":
@@ -46,15 +73,11 @@ try:
     else:
         db = None
         db_analysis = None
-        print("Beamline Database is not used in pyxrf.")
-except IOError:
-    db = None
-    print("Beamline Database is not used in pyxrf.")
+        print(f"Beamline Database is not used in pyxrf: unknown beamline {beamline_name!r}")
 
-# try:
-#     import suitcase.hdf5 as sc
-# except ImportError:
-#     pass
+except Exception as ex:
+    db = None
+    print(f"Beamline Database is not used in pyxrf: {ex}")
 
 
 def flip_data(input_data, subscan_dims=None):
@@ -683,7 +706,7 @@ def map_data2D_hxn(
     if output_to_file:
         # output to file
         print("Saving data to hdf file.")
-        fpath = write_db_to_hdf_base(
+        fpath = save_data_to_hdf5(
             fpath,
             data_out,
             metadata=mdata,
@@ -894,7 +917,7 @@ def map_data2D_srx(
                     fly_type=fly_type,
                     base_val=config_data["base_value"],
                 )  # base value shift for ic
-                fpath_out = write_db_to_hdf_base(
+                fpath_out = save_data_to_hdf5(
                     fpath_out,
                     data_out,
                     metadata=mdata,
@@ -921,7 +944,7 @@ def map_data2D_srx(
                     fly_type=fly_type,
                     base_val=config_data["base_value"],
                 )  # base value shift for ic
-                fpath_out = write_db_to_hdf_base(
+                fpath_out = save_data_to_hdf5(
                     fpath_out,
                     data_out,
                     metadata=mdata,
@@ -1223,7 +1246,7 @@ def map_data2D_srx(
             if output_to_file:
                 # output to file
                 print(f"Saving data to hdf file #{n_detectors_found}: Detector: {detector_name}.")
-                fpath_out = write_db_to_hdf_base(
+                fpath_out = save_data_to_hdf5(
                     fpath_out,
                     new_data,
                     metadata=mdata,
@@ -1383,17 +1406,24 @@ def map_data2D_tes(
         """
         Determine if the row is missing. Different versions of Databroker will return differnent value types.
         """
-        if s_data[_n] is None:
+        if row_data is None:
             return True
-        elif isinstance(s_data[_n], np.ndarray) and (s_data[_n].size == 1) and (s_data[_n] == np.array(None)):
+        elif isinstance(row_data, np.ndarray) and (row_data.size == 1) and (row_data == np.array(None)):
             # This is returned by databroker.v0
             return True
-        elif not len(s_data[_n]):
+        elif not len(row_data):
             return True
+        else:
+            return False
+
+    def _get_row_len(row_data):
+        if _is_row_missing(row_data):
+            return 0
+        else:
+            return len(row_data)
 
     # Typically the scalers are saved
     if save_scaler is True:
-
         # Read the scalers
         scaler_names = config_data["scaler_list"]
 
@@ -1412,20 +1442,27 @@ def map_data2D_tes(
             #   and then stack the arrays into a single 2D array
             s_data = s_data.to_numpy()
 
+            # Find maximum number of points in a row.
+            n_max_points = -1  # Maximum number of points in the row
+            for row_data in s_data:
+                n_max_points = max(n_max_points, _get_row_len(row_data))
+
             # Fix for the issue: 'empty' rows in scaler data. Fill 'empty' row
             #   with the nearest (preceding) row.
             # TODO: investigate the issue of 'empty' scaler ('dwell_time') rows at TES
             n_full = -1
+
             for _n in range(len(s_data)):
-                if _is_row_missing(s_data[_n]):
+                if _is_row_missing(s_data[_n]) or (len(s_data[_n]) < n_max_points):
                     n_full = _n
                     break
             for _n in range(len(s_data)):
                 # Data for the missing row is replaced by data from the previous 'good' row
-                if _is_row_missing(s_data[_n]):
+                if _is_row_missing(s_data[_n]) or (len(s_data[_n]) < n_max_points):
                     s_data[_n] = np.copy(s_data[n_full])
                     logger.error(
-                        f"Scaler '{name}': row #{_n} contains no data. Replaced by data from row #{n_full}"
+                        f"Scaler '{name}': row #{_n} is corrupt or contains no data. "
+                        f"Replaced by data from row #{n_full}"
                     )
                 else:
                     n_full = _n
@@ -1452,16 +1489,38 @@ def map_data2D_tes(
     n_events = data_shape[0]
     n_events_found = 0
     e = hdr.events(fill=True, stream_name="primary")
-    for n, v in enumerate(e):
-        if n >= n_events:
-            print("The number of lines is less than expected")
-            break
-        data = v.data[detector_field]
-        data_det1 = np.array(data[:, 0, :], dtype=np.float32)
-        detector_data[n, :, :] = data_det1
-        n_events_found = n + 1
+
+    n_pt_max = -1
+    try:
+        for n, v in enumerate(e):
+            if n >= n_events:
+                print("The number of lines is less than expected")
+                break
+            data = v.data[detector_field]
+            data_det1 = np.array(data[:, 0, :], dtype=np.float32)
+
+            # The following is the fix for the case when data has corrupt row (smaller number of data points).
+            # It will not work if the first row is corrupt.
+            n_pt_max = max(data_det1.shape[0], n_pt_max)
+            data_det1_adjusted = np.zeros([n_pt_max, data_det1.shape[1]])
+            data_det1_adjusted[: data_det1.shape[0], :] = data_det1
+
+            detector_data[n, :, :] = data_det1_adjusted
+            n_events_found = n + 1
+    except Exception as ex:
+        logger.error(f"Error occurred while reading data: {ex}. Trying to retrieve available data ...")
+
     if n_events_found < n_events:
         print("The number of lines is less than expected. The experiment may be incomplete")
+
+    if n_events_found != n_events:
+        # This will happen if data is corrupt, for example the experiment is interrupted prematurely.
+        n_events_min = min(n_events_found, n_events)
+        print(f"The map is resized: data for only {n_events_min} rows is available")
+        detector_data = detector_data[:n_events_min, :, :]
+        new_data["scaler_data"] = new_data["scaler_data"][:n_events_min, :, :]
+        new_data["pos_data"] = new_data["pos_data"][:, :n_events_min, :]
+
     # Note: the following code assumes that the detector has only one channel.
     #   If the detector is upgraded, the following code will have to be rewritten, but
     #   the rest of the data loading procedure will have to be modified anyway.
@@ -1485,7 +1544,7 @@ def map_data2D_tes(
     if output_to_file:
         # output to file
         print(f"Saving data to hdf file #{n_detectors_found}: Detector: {detector_name}.")
-        fpath_out = write_db_to_hdf_base(
+        fpath_out = save_data_to_hdf5(
             fpath_out,
             new_data,
             metadata=mdata,
@@ -1599,10 +1658,13 @@ def map_data2D_xfm(
             scaler_list=config_data["scaler_list"],
             fly_type=fly_type,
         )
+
+        fpath_out = fpath
+
         if output_to_file:
             print("Saving data to hdf file.")
-            write_db_to_hdf_base(
-                fpath,
+            fpath_out = save_data_to_hdf5(
+                fpath_out,
                 data_out,
                 metadata=mdata,
                 fname_add_version=fname_add_version,
@@ -1611,10 +1673,10 @@ def map_data2D_xfm(
             )
 
         detector_name = "xs"
-        d_dict = {"dataset": data_out, "file_name": fpath, "detector_name": detector_name, "metadata": mdata}
+        d_dict = {"dataset": data_out, "file_name": fpath_out, "detector_name": detector_name, "metadata": mdata}
         data_output.append(d_dict)
 
-        return data_output
+    return data_output
 
 
 def write_db_to_hdf(
@@ -2022,7 +2084,7 @@ def _get_fpath_not_existing(fpath):
     # Returns path to the new file that is guaranteed to not exist
     # The function cycles through paths obtained by inserting
     #   version number between name and extension in the prototype path ``fpath``
-    #  The version number is inserted in the form ``filename_(2).ext``
+    #  The version number is inserted in the form ``filename_v2.ext``
 
     if os.path.exists(fpath):
         p, e = os.path.splitext(fpath)
@@ -2035,62 +2097,97 @@ def _get_fpath_not_existing(fpath):
     return fpath
 
 
-def write_db_to_hdf_base(
+def save_data_to_hdf5(
     fpath, data, *, metadata=None, fname_add_version=False, file_overwrite_existing=False, create_each_det=True
 ):
     """
-    This is the function used to save raw experiment data into HDF5 file.
-    Typically used after data is loaded from databroker.
+    This is the function used to save raw experiment data into HDF5 file. The raw data is
+    represented as a dictionary with the following keys:
+
+      keys 'det1', 'det2' etc. - 3D ndarrays of size (N, M, K) where NxM are dimensions of the map
+      and K is the number of spectrum points (4096) contain data from the detector channels 1, 2, 3 etc.
+
+      key 'det_sum' - 3D ndarray with the same dimensions as 'det1' contains the sum of the channels
+
+      key 'scaler_names' - the list of scaler names
+
+      key 'scaler_data' - 3D ndarray of scaler values. The array shape is (N, M, P), where P is
+      the number of scaler names.
+
+      key 'pos_names' - the list of position (axis) names, must contain the names 'x_pos' and 'y_pos'
+      in correct order.
+
+      key 'pos_data' - 3D ndarray with position values. The array must have size (2, N, M). The first
+          index is the number of the position name 'pos_names' list.
 
     Parameters
     ----------
     fpath: str
-        path to save hdf file
+        Full path to the HDF5 file. The function creates an new HDF5 file. If file already exists
+        and ``file_overwrite_existing=False``, then the IOError exception is raised.
     data : dict
-        fluorescence data with scaler value and positions
-    fname_add_version : bool
+        The dictionary of raw data.
+    metadata : dict
+        Metadata to be saved in the HDF5 file. The function will add or overwrite the existing
+        metadata fields: ``file_type``, ``file_format``, ``file_format_version``, ``file_created_time``.
+        User may define metadata fields ``file_software`` and ``file_software_version``. If ``file_software``
+        is not defined, then the default values for ``file_software`` and ``file_software_version`` are added.
+    fname_add_version : boolean
         True: if file already exists, then file version is added to the file name
         so that it becomes unique in the current directory. The version is
-        added to <fname>.h5 in the form <fname>_(1).h5, <fname>_(2).h5, etc.
-        False: the exception is thrown if the file exists.
-    create_each_det : Bool, optional
-        if number of point is too large, only sum data is saved in h5 file
+        added to <fname>.h5 in the form <fname>_v1.h5, <fname>_v2.h5, etc.
+        False: the exception is raised if the file exists.
+    file_overwrite_existing : boolean
+        Overwrite the existing file or raise exception if the file exists.
+    create_each_det : boolean
+        Save data from individual detectors (``True``) or only the sum of fluorescence from
+        all detectors (``False``).
 
-    The structure of the ``data`` dictionary:
-      keys 'det1', 'det2' etc. - 2D ndarrays, data from the detector channels
-      key 'det_sum' - 2D ndarray, sum of the channels
-      key 'scaler_names' - the list of scaler names
-      key 'scaler_data' - 3D ndarray with scaler values, 1st index matches the
-              index of scaler name in 'scaler_names' list
-      key 'pos_names' - the list of position field names, must have entries 'x_pos' and 'y_pos'
-      key 'pos_data' - 3D ndarray, 1st index matches the position in 'pos_names' list
+    Raises
+    ------
+    IOError
+        Failed to write data to HDF5 file.
     """
 
+    fpath = os.path.expanduser(fpath)
+    fpath = os.path.abspath(fpath)
+
+    data = data.copy()  # Must be a shallow copy (avoid creating copies of data arrays)
+    metadata = copy.deepcopy(metadata)  # Create deep copy (metadata is modified)
+
     interpath = "xrfmap"
-    sum_data = None
+    sum_data, sum_data_exists = None, False
     xrf_det_list = [n for n in data.keys() if "det" in n and "sum" not in n]
     xrf_det_list.sort()
 
     # Verify that raw fluorescence data is represented with np.float32 precision: print the warning message
     #   and convert the raw spectrum data to np.float32. Assume that data is represented as ndarray.
     def incorrect_type_msg(channel, data_type):
-        logger.warning(
+        logger.debug(
             f"Attemptying to save raw fluorescence data for the channel '{channel}' "
             f"as '{data_type}' numbers.\n    Memory may be used inefficiently. "
-            f"Please, inform the PyXRF developers.\n    The data is converted from '{data_type}' "
-            f"to 'np.float32' before saving to file."
+            f"The data is converted from '{data_type}' to 'np.float32' before saving to file."
         )
 
     if "det_sum" in data and isinstance(data["det_sum"], np.ndarray):
         if data["det_sum"].dtype != np.float32:
             incorrect_type_msg("det_sum", data["det_sum"].dtype)
             data["det_sum"] = data["det_sum"].astype(np.float32, copy=False)
+        sum_data = data["det_sum"]
+        sum_data_exists = True
+
     for detname in xrf_det_list:
         if detname in data and isinstance(data[detname], np.ndarray):
             if data[detname].dtype != np.float32:
                 incorrect_type_msg(detname, data[detname].dtype)
                 data[detname] = data[detname].astype(np.float32, copy=False)
 
+            if not sum_data_exists:  # Don't compute it if it already exists
+                if sum_data is None:
+                    sum_data = np.copy(data[detname])
+                else:
+                    sum_data += data[detname]
+
     file_open_mode = "a"
     if os.path.exists(fpath):
         if fname_add_version:
@@ -2102,43 +2199,42 @@ def write_db_to_hdf_base(
                 #   including all information (possibly processed results).
                 file_open_mode = "w"
             else:
-                raise IOError(f"'write_db_to_hdf_base': File '{fpath}' already exists.")
+                raise IOError(f"Function 'save_data_to_hdf5': File '{fpath}' already exists")
 
     with h5py.File(fpath, file_open_mode) as f:
 
         # Create metadata group
         metadata_grp = f.create_group(f"{interpath}/scan_metadata")
-        # This group of attributes are always created. It doesn't matter if metadata
-        #   is provided to the function.
-        metadata_grp.attrs["file_type"] = "XRF-MAP"
-        metadata_grp.attrs["file_format"] = "NSLS2-XRF-MAP"
-        metadata_grp.attrs["file_format_version"] = "1.0"
-        metadata_grp.attrs["file_software"] = "PyXRF"
-        metadata_grp.attrs["file_software_version"] = pyxrf_version
-        # Present time in NEXUS format (should it be UTC time)?
-        metadata_grp.attrs["file_created_time"] = ttime.strftime("%Y-%m-%dT%H:%M:%S+00:00", ttime.localtime())
 
-        # Now save the rest of the scan metadata if metadata is provided
-        if metadata:
+        metadata_additional = {
+            "file_type": "XRF-MAP",
+            "file_format": "NSLS2-XRF-MAP",
+            "file_format_version": "1.0",
+            "file_created_time": ttime.strftime("%Y-%m-%dT%H:%M:%S+00:00", ttime.localtime()),
+        }
+
+        metadata_software_version = {
+            "file_software": "PyXRF",
+            "file_software_version": pyxrf_version,
+        }
+
+        metadata_prepared = metadata or {}
+        metadata_prepared.update(metadata_additional)
+        if "file_software" not in metadata_prepared:
+            metadata_prepared.update(metadata_software_version)
+
+        if metadata_prepared:
             # We assume, that metadata does not contain repeated keys. Otherwise the
             #   entry with the last occurrence of the key will override the previous ones.
-            for key, value in metadata.items():
+            for key, value in metadata_prepared.items():
                 metadata_grp.attrs[key] = value
 
         if create_each_det is True:
             for detname in xrf_det_list:
                 new_data = data[detname]
-
-                if sum_data is None:
-                    sum_data = np.copy(new_data)
-                else:
-                    sum_data += new_data
-
                 dataGrp = f.create_group(interpath + "/" + detname)
                 ds_data = dataGrp.create_dataset("counts", data=new_data, compression="gzip")
                 ds_data.attrs["comments"] = "Experimental data from {}".format(detname)
-        else:
-            sum_data = data["det_sum"]
 
         # summed data
         if sum_data is not None:
@@ -2165,6 +2261,9 @@ def write_db_to_hdf_base(
     return fpath
 
 
+write_db_to_hdf_base = save_data_to_hdf5  # Backward compatibility
+
+
 '''
 # This may not be needed, since hdr always goes out of scope
 def clear_handler_cache(hdr):
